@@ -153,6 +153,8 @@ class Range:
         # process kwargs
         start = kwargs.get("start", _InfiniteValue(negative=True))
         end = kwargs.get("end", _InfiniteValue(negative=False))
+        if end is None:
+            end = _InfiniteValue(negative=False)
         include_start = kwargs.get("include_start", True)
         include_end = kwargs.get("include_end", False)
         self.include_start = include_start
@@ -217,7 +219,7 @@ class Range:
             # removed: construct from iterable representing start/end
             else:
                 raise ValueError(
-                    f"cannot construct a new Range from an object of type '{type(rng)}'"
+                    f"cannot construct a new {self.__class__.__name__} from an object of type '{type(rng)}'"
                 )
         else:
             # case 4 or 5: construct from positional args or kwargs
@@ -282,7 +284,7 @@ class Range:
         # convert other range to a format we can really work with
         try:
             if not isinstance(rng, Range):
-                rng = Range(rng)
+                rng = self.__class__(rng)
         except ValueError:
             raise TypeError("Cannot merge a Range with a non-Range")
         # do the ranges overlap?
@@ -298,7 +300,7 @@ class Range:
             key=lambda x: (x[0], not x[1]),
         )
         new_end = max((rng_a.end, rng_a.include_end), (rng_b.end, rng_b.include_end))
-        return Range(
+        return self.__class__(
             start=new_start[0],
             end=new_end[0],
             include_start=new_start[1],
@@ -371,7 +373,7 @@ class Range:
         # convert other range to a workable format
         try:
             if not isinstance(rng, Range):
-                rng = Range(rng)
+                rng = self.__class__(rng)
         except ValueError:
             raise TypeError("Cannot diff a Range with a non-Range")
         # completely disjoint
@@ -384,13 +386,13 @@ class Range:
             return None
         # fully contained (in the other direction)
         elif rng in self:
-            lower = Range(
+            lower = self.__class__(
                 start=self.start,
                 end=rng.start,
                 include_start=self.include_start,
                 include_end=not rng.include_start,
             )
-            upper = Range(
+            upper = self.__class__(
                 start=rng.end,
                 end=self.end,
                 include_start=not rng.include_end,
@@ -405,7 +407,7 @@ class Range:
                 return RangeSet(lower, upper)
         # lower portion of this range
         elif self < rng:
-            new_rng = Range(
+            new_rng = self.__class__(
                 start=self.start,
                 end=rng.start,
                 include_start=self.include_start,
@@ -414,7 +416,7 @@ class Range:
             return None if new_rng.isempty() else new_rng
         # higher portion of this range
         else:  # self > rng:
-            new_rng = Range(
+            new_rng = self.__class__(
                 start=rng.end,
                 end=self.end,
                 include_start=not rng.include_end,
@@ -678,7 +680,10 @@ class Range:
                 return self._above_start(item) and self._below_end(item)
             except TypeError:
                 try:
-                    rng_item = Range(item)
+                    if isinstance(item, Range):
+                        rng_item = item
+                    else:
+                        rng_item = Range(item)
                     return rng_item.start in self and rng_item.end in self
                 except ValueError:
                     pass
@@ -867,7 +872,8 @@ class RangeSet(Iterable):
         # elif _is_iterable_non_string(rng):
         #     raise ValueError("argument is iterable and not range-like. Use .difference_update() instead")
         # make sure rng is a Range
-        rng = Range(rng)
+        if not isinstance(rng, Range):
+            rng = Range(rng)
         # remove rng from our ranges until we no longer need to
         current_node = self._ranges.first
         while current_node:
@@ -904,7 +910,7 @@ class RangeSet(Iterable):
         RangeSet is not modified in the process.
         """
         new_rng_set = self.copy()
-        new_rng_set.difference_update(RangeSet(rng_set))
+        new_rng_set.difference_update(self.__class__(rng_set))
         return new_rng_set
 
     def difference_update(self, rng_set):
@@ -951,7 +957,7 @@ class RangeSet(Iterable):
         # convert to RangeSet
         rng_set = RangeSet._to_rangeset(rng_set)
         # simply merge lists
-        return RangeSet(self._ranges + rng_set._ranges)
+        return self.__class__(self._ranges + rng_set._ranges)
 
     def update(self, rng_set):
         """
@@ -1063,7 +1069,7 @@ class RangeSet(Iterable):
         """
         returns a shallow copy of this RangeSet
         """
-        return RangeSet(self)
+        return self.__class__(self)
 
     @staticmethod
     def _merge_ranges(ranges):
@@ -1091,8 +1097,8 @@ class RangeSet(Iterable):
                 node = node.next
         return ranges
 
-    @staticmethod
-    def _to_rangeset(other):
+    @classmethod
+    def _to_rangeset(cls, other):
         """
         Helper method.
         Converts the given argument to a RangeSet. This mainly exists to increase performance
@@ -1101,7 +1107,7 @@ class RangeSet(Iterable):
         """
         if not isinstance(other, RangeSet):
             try:
-                other = RangeSet(other)
+                other = cls(other)
             except ValueError:
                 raise ValueError(f"Cannot convert {type(other)} to a RangeSet")
         return other
